@@ -3,7 +3,7 @@ package JSON::Schema::Modern::Vocabulary::OpenAPI;
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Implementation of the JSON Schema OpenAPI vocabulary
 
-our $VERSION = '0.052';
+our $VERSION = '0.053';
 
 use 5.020;
 use Moo;
@@ -118,7 +118,7 @@ JSON::Schema::Modern::Vocabulary::OpenAPI - Implementation of the JSON Schema Op
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 DESCRIPTION
 
@@ -163,7 +163,7 @@ L<https://www.openapis.org/>
 
 =item *
 
-L<https://oai.github.io/Documentation/>
+L<https://learn.openapis.org/>
 
 =item *
 
