@@ -1,10 +1,10 @@
 use strictures 2;
-package OpenAPI::Modern; # git description: v0.051-6-g33162f8
+package OpenAPI::Modern; # git description: v0.052-5-g17f14aa
 # vim: set ts=8 sts=2 sw=2 tw=100 et :
 # ABSTRACT: Validate HTTP requests and responses against an OpenAPI v3.1 document
 # KEYWORDS: validation evaluation JSON Schema OpenAPI v3.1 Swagger HTTP request response
 
-our $VERSION = '0.052';
+our $VERSION = '0.053';
 
 use 5.020;
 use utf8;
@@ -239,11 +239,6 @@ sub validate_response ($self, $response, $options = {}) {
 
     $response = _convert_response($response);   # now guaranteed to be a Mojo::Message::Response
 
-    if (my $error = $response->error) {
-      ()= E($state, $error->{message});
-      return $self->_result($state, 1);
-    }
-
     if ($response->headers->header('Transfer-Encoding')) {
       ()= E({ %$state, data_path => jsonp($state->{data_path}, qw(header Transfer-Encoding)) },
         'RFC9112 §6.1-10: A server MUST NOT send a Transfer-Encoding header field in any response with a status code of 1xx (Informational) or 204 (No Content)')
@@ -326,6 +321,7 @@ sub find_path ($self, $options) {
     $options->{request} ? ( effective_base_uri => Mojo::URL->new->scheme('https')->host($options->{request}->headers->host) ) : (),
   };
 
+  # requests don't have response codes, so if 'error' is set, it is some sort of parsing error
   if ($options->{request} and my $error = $options->{request}->error) {
     ()= E({ %$state, data_path => '/request' }, $error->{message});
     return $self->_result($state, 1);
@@ -771,7 +767,6 @@ sub _evaluate_subschema ($self, $dataref, $schema, $state) {
       data_path => $state->{data_path},
       traversed_schema_path => $state->{traversed_schema_path}.$state->{schema_path},
       effective_base_uri => $state->{effective_base_uri},
-      collect_annotations => 1,
       $state->{stringy_numbers} ? ( stringy_numbers => 1 ) : (),
     },
   );
@@ -853,7 +848,7 @@ OpenAPI::Modern - Validate HTTP requests and responses against an OpenAPI v3.1 d
 
 =head1 VERSION
 
-version 0.052
+version 0.053
 
 =head1 SYNOPSIS
 
@@ -1222,6 +1217,10 @@ L<Mojolicious::Plugin::OpenAPI::Modern>
 
 =item *
 
+L<Test::Mojo::Role::OpenAPI::Modern>
+
+=item *
+
 L<JSON::Schema::Modern::Document::OpenAPI>
 
 =item *
@@ -1238,7 +1237,7 @@ L<https://www.openapis.org/>
 
 =item *
 
-L<https://oai.github.io/Documentation/>
+L<https://learn.openapis.org/>
 
 =item *
 
